Returns a structured report rather than throwing an error. NULL
weights are valid (interpreted as unit weights) and return
ok = TRUE.
Returns a structured report rather than throwing an error. NULL
weights are valid (interpreted as unit weights) and return
ok = TRUE.