Print a CTA tree in MegaODA node table format
print.cta_tree.RdDisplays each split node with its attribute, depth, n, p-value, ESS, LOO status, and rule string, followed by the node confusion matrix.
Usage
# S3 method for class 'cta_tree'
print(x, ...)Arguments
- x
A
cta_treefromoda_cta_fit.- ...
Unused.