Prints a concise summary: anchor type, number of stages, selected attributes, implementation status. Does not claim SORT or GORT are implemented.
Usage
# S3 method for class 'sda_anchor'
print(x, ...)Prints a concise summary: anchor type, number of stages, selected attributes, implementation status. Does not claim SORT or GORT are implemented.
# S3 method for class 'sda_anchor'
print(x, ...)