Classify new observations using a CTA tree
predict.cta_tree.RdApplies a fitted cta_tree to new data by routing each observation
through the tree until it reaches a leaf node.
Arguments
- object
A
cta_treefromoda_cta_fit.- newdata
Data frame or matrix with the same columns as training X.
- missing_action
How to handle observations whose split attribute is missing on their traversal path.
"majority"(default) routes the observation to the current node's majority class."na"returnsNA_integer_for that observation (canonical path-local missingness).- ...
Unused.