Return the selected attribute names from an SDA procedure result
Source:R/sda_interop.R
sda_selected_attributes.RdReturns the names of attributes selected across all SDA steps, in step order. This is the constrained candidate set to pass to MDSA/CTA.