Returns a named list with the key structural fields needed to audit the anchor or pass it to future SORT / staged-CTA pipelines.
Usage
# S3 method for class 'sda_anchor'
summary(object, ...)Returns a named list with the key structural fields needed to audit the anchor or pass it to future SORT / staged-CTA pipelines.
# S3 method for class 'sda_anchor'
summary(object, ...)